<?php
/**
 * @file
 * picture_password.admin.inc
 *
 * Configuration options for Picture Password module.
 */

/**
 * Menu callback for admin configuration settings.
 */
function picture_password_admin_configure($form, &$form_state) {

  // Display the current Kaje system status as an informational msg.
  $response = picture_password_kaje_call('status');
  drupal_set_message($response->msg);

  $form = array();
  $form['requesting_party'] = array(
    '#type' => 'fieldset',
    '#title' => t('Requesting Party ID and Secret'),
    '#collapsible' => FALSE,
  );
  $form['requesting_party']['picture_password_rp_id'] = array(
    '#type' => 'textfield',
    '#title' => t('ID:'),
    '#description' => t('The Requestion Party ID as obtained from Kaje'),
    '#default_value' => variable_get('picture_password_rp_id'),
  );
  $form['requesting_party']['picture_password_rp_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Secret:'),
    '#description' => t('The Requestion Party Secret as obtained from Kaje'),
    '#default_value' => variable_get('picture_password_rp_secret'),
  );
  $form['buttons'] = array(
    '#type' => 'fieldset',
    '#title' => t('Login buttons'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['buttons']['picture_password_login_button_std_label'] = array(
    '#type' => 'textfield',
    '#title' => t('Label on default login button:'),
    '#description' => t('Leave blank to default to core. Use <em>&lt;no button&gt;</em> to suppress the default button altogether, so that the user can log in only with Kaje Picture Password.'),
    '#default_value' => variable_get('picture_password_login_button_std_label'),
  );
  $form['buttons']['picture_password_login_button_label'] = array(
    '#type' => 'textfield',
    '#title' => t('Label on Kaje Picture Password login button:'),
    '#description' => t('When left blank, defaults to %label', array('%label' => PICTURE_PASSWORD_LOGIN_BUTTON_LABEL)),
    '#default_value' => variable_get('picture_password_login_button_picture_password_label'),
  );
  return system_settings_form($form);
}

/**
 * Menu callback for the Kaje user administration functions menu tab.
 *
 * @param array $form
 *   The form (stub).
 * @param array $form_state
 *   The form sate.
 * @param object $account
 *   The user account.
 *
 * @return array
 *   The form with additions
 */
function picture_password_user_admin($form, &$form_state, $account = NULL) {

  global $user;
  if (!isset($account)) {
    $account = $user;
  }
  if (!picture_password_get_kaje_uid($account->uid)) {
    $form['no_kaje_uid'] = array(
      '#type' => 'markup',
      '#markup' => t('This user is not known to have a Kaje account. <br/>Kaje user administration functions for this user are therefore not available.'),
    );
    return $form;
  }

  $form['account'] = array(
    '#type' => 'value',
    '#value' => $account,
  );
  $options = array(
    PICTURE_PASSWORD_RESET_KAJE_ACCOUNT => t('Reset'),
    PICTURE_PASSWORD_SUSPEND_KAJE_ACCOUNT => t('Suspend'),
    PICTURE_PASSWORD_UNSUSPEND_KAJE_ACCOUNT => t('Unsuspend'),
    PICTURE_PASSWORD_LOCK_KAJE_ACCOUNT => t('Lock'),
    PICTURE_PASSWORD_UNLOCK_KAJE_ACCOUNT => t('Unlock'),
    PICTURE_PASSWORD_DELETE_KAJE_ACCOUNT => t('Delete (no undo)'),
  );
  $form['picture_password_admin_function'] = array(
    '#type' => 'radios',
    '#required' => TRUE,
    '#title' => t("Invoke administration function for this user's Kaje account:"),
    '#description' => t('None of these affect the @status status of this user on this website.', array(
      '@status' => user_is_blocked($account->name) ? t('blocked') : t('active')
    )),
    '#options' => $options,
    '#default_value' => 0,
  );
  $form['actions'] = array(
    '#type' => 'actions',
    'submit' => array(
      '#type' => 'submit',
      '#value' => t('Submit to Kaje'),
    ),
  );
  return $form;
}

/**
 * Submit handler for picture_password_admin_user().
 */
function picture_password_user_admin_submit($form, &$form_state) {

  $account = $form_state['values']['account'];
  $kaje_uid = picture_password_get_kaje_uid($account->uid);

  switch ($form_state['values']['picture_password_admin_function']) {
    case PICTURE_PASSWORD_RESET_KAJE_ACCOUNT:
      picture_password_set_flags($account->uid, PICTURE_PASSWORD_RESET_KAJE_ACCOUNT);
      drupal_set_message(t('The Kaje account has been flagged for a reset the next time user %name logs in.', array(
        '%name' => $account->name,
      )));
      return;

    case PICTURE_PASSWORD_LOCK_KAJE_ACCOUNT:
      $response = picture_password_kaje_call('lock', $kaje_uid);
      break;

    case PICTURE_PASSWORD_UNLOCK_KAJE_ACCOUNT:
      $response = picture_password_kaje_call('unlock', $kaje_uid);
      break;

    case PICTURE_PASSWORD_SUSPEND_KAJE_ACCOUNT:
      $response = picture_password_kaje_call('suspend', $kaje_uid);
      break;

    case PICTURE_PASSWORD_UNSUSPEND_KAJE_ACCOUNT:
      $response = picture_password_kaje_call('unsuspend', $kaje_uid);
      break;

    case PICTURE_PASSWORD_DELETE_KAJE_ACCOUNT:
      $response = picture_password_kaje_call('deleteUser', $kaje_uid);
      if ($response->user_status == 'nonexistent') {
        picture_password_delete_uid($account->uid);
      }
      break;

    default:
      drupal_set_message(t('Invalid Picture Password administration function.'), 'error');
      return;
  }
  drupal_set_message(empty($response->user_status) ? $response->msg : picture_password_user_status($response->user_status));
}
